# addcliopts.tcl
# add 'cliopts' to each scene, as specified in the scene, or, if missing,
# using a middle-of-the-road default set.

package require sqlite3

array set cfg {
  dbfn  /tmp/cmpimg.sqlite
  dflt  {+w320 +h240 +a0.3}
  grep  {grep -i {^\s*//\s*[+-]w}}
  upd1  {UPDATE scenes SET cliopts = '%s' WHERE id = %d;}
  upd2  {UPDATE scenes SET cliopts = '%s', notes = '%s' WHERE id = %d;}
  vers  202009.1
}
set cfg(self) [file tail $argv0]


proc grep {fn} {
  global cfg
  set cmd [list exec -ignorestderr {*}$cfg(grep) $fn]
  if {[catch {{*}$cmd} what]} {set rtn [list $cfg(dflt)]} \
  else {
    set rtn [list]
    set tmp [split $what \n]
    foreach el $tmp {
      lappend rtn [lrange $el 1 end]
    }
  }
  return $rtn
}

proc mkFn {d s} {format %s.pov [file join $d $s]}


sqlite3 dbc $cfg(dbfn) -create 0

dbc eval {PRAGMA foreign_keys = 1;}

dbc eval {SELECT * FROM vactive;} rcd {
  set o [grep [mkFn $rcd(folder) $rcd(scene)]]
  if {1 == [llength $o]} {
    set q [format $cfg(upd1) [lindex $o 0] $rcd(id)]
  } \
  else {
    set s [join [lrange $o 0 end-1] \n]
    set q [format $cfg(upd2) [lindex $o end] $s $rcd(id)]
  }
  dbc eval $q
}

dbc close

return

