# addscenes.tcl
# populates the 'cmpimg' db 'scenes' table.

package require sqlite3

array set cfg {
  dbfn  /tmp/cmpimg.sqlite
  vers  202009.1
}
set cfg(self) [file tail $argv0]


# retrieve set of directories with ids.

set dirs [list]

sqlite3 dbc $cfg(dbfn) -create 0 -readonly 1

dbc eval {SELECT folder, id FROM folders ORDER BY id;} {
  lappend dirs $folder $id
}

dbc close

if {![llength $dirs]} {
  puts stderr [format {%s: error no records.} $cfg(self)]
  return
}

# loop while there are lines on stdin.
# separate file name from its directory,
# remove extension from file name,
# get id for directory - not found error,
# store (base) file name and directory id in list.

set files [list]
set line [gets stdin]
while {![eof stdin]} {
  set tlist [file split $line]
  set tfn [file rootname [lindex $tlist end]]
  set tdir [file join {*}[lrange $tlist 0 end-1]]
  set i [lsearch -exact $dirs $tdir]
  if {-1 == $i} {
    puts stderr [format {%s: error no record for '%s'.} $cfg(self) $tdir]
    return
  }
  incr i
  lappend files $tfn [lindex $dirs $i]
  set line [gets stdin]
}

if {![llength $files]} {
  puts stderr [format {%s: error no input(s).} $cfg(self)]
  return
}

# output SQL.

puts {PRAGMA foreign_keys = 1;}

puts {INSERT INTO scenes (scene, foldid) VALUES }

foreach {fn id} [lrange $files 0 end-2] {
  puts [format {('%s',%d), } $fn $id]
}

puts [format {('%s',%d);} [lindex $files end-1] [lindex $files end]]

# done.

return

