-- mkcmpimg/init-db.sql
--  v 0.1

-- ----------------------------------------------------------------------------
-- database stuff
-- ----------------------------------------------------------------------------

PRAGMA page_size = 1024;

PRAGMA user_version = 1;

-- ----------------------------------------------------------------------------
-- folders
-- stores the directories relative to '/usr/local/share/povray-3.7/scenes/'.
-- ----------------------------------------------------------------------------

CREATE TABLE folders  (
  id INTEGER PRIMARY KEY,
  active INTEGER NOT NULL DEFAULT 1,
  folder TEXT NOT NULL UNIQUE
);

-- ----------------------------------------------------------------------------
-- scenes
-- stores the scene files (*.pov) found in 'folders'.
--   'scene' file root name w/out extension.
--   'cliopts' string/list as given in each scene's header.
--   'orient' set to '1' when montage should be vertical.
-- ----------------------------------------------------------------------------

CREATE TABLE scenes (
  id INTEGER PRIMARY KEY,
  active INTEGER NOT NULL DEFAULT 1,
  scene TEXT NOT NULL,
  cliopts TEXT,
  orient INTEGER NOT NULL DEFAULT 0,
  foldid INTEGER NOT NULL,
  notes TEXT,
  FOREIGN KEY (foldid) REFERENCES folders (id)
          ON DELETE RESTRICT
          ON UPDATE NO ACTION
);

-- ----------------------------------------------------------------------------
-- cf 'mkcmpimgs.tcl' and 'addcliopts.tcl'.
-- ----------------------------------------------------------------------------

CREATE VIEW vactive AS
  SELECT a.scene AS scene,
         a.cliopts AS cliopts,
         a.orient AS orient,
         b.folder AS folder,
         a.id AS id
    FROM scenes AS a JOIN folders AS b ON a.foldid = b.id
   WHERE a.active = 1 AND b.active = 1
ORDER BY a.id;

