# mkcmpimgs.tcl
# render each active scene in db, with v37 and v38 POV-Rays.
# create a 'montage' of each image pair, then delete the pair.
# assume run in copy of 'scenes' directory.

package require sqlite3

array set cfg {
  dbfn  /tmp/cmpimg.sqlite
  mont  {montage %s %s -tile %s -geometry +0+0 %s}
  povr  {povray-3.7.0.8 povray-3.8.0-alpha.10064268}
  tags  {v37 v38}
  vers  202009.1
}
set cfg(self) [file tail $argv0]


proc mcmd {s o} {
  global cfg
  set f1 [format %s_%s.png [lindex $cfg(tags) 0] $s]
  set f2 [format %s_%s.png [lindex $cfg(tags) 1] $s]
  set f3 [format cmp_%s.png $s]
  if {$o} {set ts 1x2} else {set ts 2x1}
  set m [format $cfg(mont) $f1 $f2 $ts $f3]
  set cmd [list exec -ignorestderr {*}$m]
# {*}$cmd
puts [format {mcmd: %s} $cmd]
  return
}

proc pcmd {i s o} {
  global cfg
  set f1 [format %s.pov $s]
  set f2 [format %s_%s [lindex $cfg(tags) $i] $s]
  set cmd [list exec -ignorestderr [lindex $cfg(povr) $i] +i$f1 {*}$o -p +o$f2]
# {*}$cmd
puts [format {pcmd: %s} $cmd]
  return
}

proc rcmd {s} {
  global cfg
# foreach t $cfg(tags) {file delete [format %s_%s.png $t $s]}
foreach t $cfg(tags) {puts [format {rcmd: rm -f %s} [format %s_%s.png $t $s]]}
  return
}


set odir [pwd]

sqlite3 dbc $cfg(dbfn) -create 0 -readonly 1

dbc eval {PRAGMA foreign_keys = 1;}

dbc eval {SELECT * FROM vactive;} rcd {
  cd $rcd(folder)
  pcmd 0 $rcd(scene) $rcd(cliopts)
  pcmd 1 $rcd(scene) $rcd(cliopts)
  mcmd $rcd(scene) $rcd(orient)
  rcmd $rcd(scene)
  cd $odir
}

dbc close

return

